@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # package exports and version
-our $VERSION   = '0.17';
+our $VERSION = '0.18';
 
 # module imports
 use Padre::Wx ();
@@ -26,6 +26,16 @@ sub padre_interfaces {
 	return 'Padre::Plugin' => 0.43;
 }
 
+#
+# private subroutine to return the current share directory location
+# We will keep this until Module::Build get its own sharedir installation feature
+#
+sub _sharedir {
+	return Cwd::realpath( 
+		File::Spec->join( 
+			File::Basename::dirname(__FILE__), 'Ecliptic' , 'share' ) );
+}
+
 #
 # plugin's real icon...
 #
@@ -43,8 +53,9 @@ sub logo_icon {
 #
 sub plugin_icon {
 	my $self = shift;
+
 	# find resource path
-	my $iconpath = File::Spec->catfile( $self->plugin_directory_share, 'icons', 'ecliptic.png' );
+	my $iconpath = File::Spec->catfile( $self->_sharedir, 'icons', 'ecliptic.png' );
 
 	# create and return icon
 	return Wx::Bitmap->new( $iconpath, Wx::wxBITMAP_TYPE_PNG );
@@ -102,13 +113,6 @@ sub menu_plugins {
 		sub { $self->_show_quick_module_access_dialog(); },
 	);
 
-	# Shows the "Quick Fix" dialog
-	Wx::Event::EVT_MENU(
-		$main_window,
-		$self->{menu}->Append( -1, Wx::gettext("Quick Fix\tCtrl-Shift-1"), ),
-		sub { $self->_show_quick_fix_dialog },
-	);
-
 	#---------
 	$self->{menu}->AppendSeparator;
 
@@ -180,22 +184,6 @@ sub _show_quick_module_access_dialog {
 	return;
 }
 
-#
-# Shows the quick fix dialog
-#
-sub _show_quick_fix_dialog {
-	my $self = shift;
-
-	#Create and show the dialog
-	require Padre::Plugin::Ecliptic::QuickFixDialog;
-	my $dialog = Padre::Plugin::Ecliptic::QuickFixDialog->new($self);
-	if ($dialog) {
-		$dialog->Show(1);
-	}
-
-	return;
-}
-
 1;
 
 __END__
@@ -230,34 +218,6 @@ button, the outline element in the outline tree will be selected.
 This opens a dialog where you can search for a CPAN module. When you hit the OK 
 button, the selected module will be displayed in Padre's POD browser.
 
-=head2 Quick Fix (Shortcut: Ctrl + Shift + 1)
-
-This opens a dialog that lists different actions that relate to 
-fixing the code at the cursor. It will call B<event_on_quick_fix> method 
-passing a L<Padre::Wx::Editor> object on the current Padre document. 
-Please see the following sample implementation:
-
-	sub event_on_quick_fix {
-		my ($self, $editor) = @_;
-		
-		my @items = ( 
-			{
-				text     => '123...', 
-				listener => sub { 
-					print "123...\n";
-				} 
-			},
-			{
-				text     => '456...', 
-				listener => sub { 
-					print "456...\n";
-				} 
-			},
-		);
-		
-		return @items;
-	}
-
 =head2 About
 
 Shows a classic about dialog with this module's name and version.
